@@ -11,7 +11,8 @@ from mpl_format.axes import AxisFormatter
 from mpl_format.axes.axes_formatter import AxesFormatter
 from mpl_format.axes.axes_formatter_array import AxesFormatterArray
 from mpl_format.axes.axis_formatter_array import AxisFormatterArray
-from mpl_format.compound_types import StringMapper
+from mpl_format.compound_types import StringMapper, Color
+from mpl_format.enums.line_style import LINE_STYLE
 from mpl_format.utils.io_utils import save_plot
 
 TextSetter = TypeVar(
@@ -89,11 +90,19 @@ class FigureFormatter(object):
             axes = empty_like(self._axes, dtype=AxisFormatter)
             if axes.ndim == 1:
                 for i in range(self._axes.shape[0]):
-                    axes[i] = AxisFormatter(self._axes[i].xaxis)
+                    axes[i] = AxisFormatter(
+                        axis=self._axes[i].xaxis,
+                        direction='x',
+                        axes=self._axes[i]
+                    )
             elif axes.ndim == 2:
                 for i in range(axes.shape[0]):
                     for j in range(axes.shape[1]):
-                        axes[i, j] = AxisFormatter(self._axes[i, j].xaxis)
+                        axes[i, j] = AxisFormatter(
+                            axis=self._axes[i, j].xaxis,
+                            direction='x',
+                            axes=self._axes[i, j]
+                        )
 
         return AxisFormatterArray(axes)
 
@@ -109,11 +118,19 @@ class FigureFormatter(object):
             axes = empty_like(self._axes, dtype=AxisFormatter)
             if axes.ndim == 1:
                 for i in range(self._axes.shape[0]):
-                    axes[i] = AxisFormatter(self._axes[i].yaxis)
+                    axes[i] = AxisFormatter(
+                        axis=self._axes[i].yaxis,
+                        direction='y',
+                        axes=self._axes[i]
+                    )
             elif axes.ndim == 2:
                 for i in range(axes.shape[0]):
                     for j in range(axes.shape[1]):
-                        axes[i, j] = AxisFormatter(self._axes[i, j].yaxis)
+                        axes[i, j] = AxisFormatter(
+                            axis=self._axes[i, j].yaxis,
+                            direction='y',
+                            axes=self._axes[i, j]
+                        )
 
         return AxisFormatterArray(axes)
 
@@ -188,6 +205,15 @@ class FigureFormatter(object):
                 )
         return self
 
+    def set_title(self, text) -> 'FigureFormatter':
+        """
+        Set the title of the Figure.
+
+        :param text: The text for the title.
+        """
+        self._figure.suptitle(t=text)
+        return self
+
     def set_axes_title_text(
             self,
             text: TextSetter
@@ -623,6 +649,8 @@ class FigureFormatter(object):
 
     # endregion
 
+    # region margins
+
     def subplots_adjust(
             self,
             left: Optional[float] = None, right: Optional[float] = None,
@@ -736,6 +764,43 @@ class FigureFormatter(object):
         self.subplots_adjust(h_space=spacing)
         return self
 
+    # endregion
+
+    def grids(
+            self, value: bool = True,
+            which: str = 'major',
+            axis: str = 'both',
+            color: Optional[Color] = None,
+            line_width: Optional[float] = None,
+            line_style: Optional[Union[str, LINE_STYLE]] = None
+    ) -> 'FigureFormatter':
+        """
+        Turn the grid on or off.
+
+        :param value: True or False. Defaults to True.
+        :param which: 'major', 'minor' or 'both'
+        :param axis: 'x', 'y' or 'both.
+        :param color: Color of the lines.
+        :param line_width: Line width.
+        :param line_style: Line Style. One of {'-', '--', '-.', ':', '',
+                           (offset, on-off-seq), ...}
+        """
+        for axes in self.axes.flat:
+            axes.grid(value=value, which=which, axis=axis,
+                      color=color, line_width=line_width,
+                      line_style=line_style)
+        return self
+
+    def set_axes_below(self, value: bool = True) -> 'FigureFormatter':
+        """
+        Set whether axis ticks and gridlines are above or below most artists.
+
+        :param value: True or False
+        """
+        for axes in self.axes.flat:
+            axes.set_axis_below(value=value)
+        return self
+
     def tight_layout(self) -> 'FigureFormatter':
         """
         Call the tight_layout method on the wrapped Figure.
@@ -743,6 +808,62 @@ class FigureFormatter(object):
         self.figure.tight_layout()
         return self
 
+    # region limits
+
+    def set_x_lims(self, left: Optional[float] = None,
+                   right: Optional[float] = None) -> 'FigureFormatter':
+        """
+        Set the limits of the x-axes.
+
+        :param left: Lower limit.
+        :param right: Upper limit.
+        """
+        for axf in self.multi.flat:
+            axf.set_x_lim(left=left, right=right)
+        return self
+
+    def set_y_lims(self, bottom: Optional[float] = None,
+                   top: Optional[float] = None) -> 'FigureFormatter':
+        """
+        Set the limits of the y-axes.
+
+        :param bottom: Lower limit.
+        :param top: Upper limit.
+        """
+        for axf in self.multi.flat:
+            axf.set_y_lim(bottom=bottom, top=top)
+        return self
+
+    def set_x_mins(self, left: float = None) -> 'FigureFormatter':
+        """
+        Set the x-axes lower view limit.
+        """
+        self.set_x_lims(left, None)
+        return self
+
+    def set_x_maxes(self, right: float = None) -> 'FigureFormatter':
+        """
+        Set the x-axes upper view limit.
+        """
+        self.set_x_lims(None, right)
+        return self
+
+    def set_y_mins(self, bottom: float = None) -> 'FigureFormatter':
+        """
+        Set the y-axes lower view limit.
+        """
+        self.set_y_lims(bottom, None)
+        return self
+
+    def set_y_maxes(self, top: float = None) -> 'FigureFormatter':
+        """
+        Set the y-axes upper view limit.
+        """
+        self.set_y_lims(None, top)
+        return self
+
+    # endregion
+
     def save(
             self,
             file_path: Union[str, Path],
